@@ -292,14 +292,15 @@ def get_version():
             )
 
 
-def run_tests(test_path=None):
+def run_tests(test_path=None, test_coverage=False):
     import pytest
 
     """Run tests. If any test fails, raise an error.
 
     Args:
-        test_path ((str, pathlib.Path)), optional): Usually autodetected (if root_path / tests).
+        test_path ((str, pathlib.Path), optional): Usually autodetected (if root_path / tests).
             Defaults to None.
+        test_coverage(bool, optional): Whether run test coverage plugin. If True, pytest-cov must be installed. Defaults to True
 
     Raises:
         Exception: If any test fail, it will raise exception (git hook do not continue...).
@@ -308,7 +309,12 @@ def run_tests(test_path=None):
     if not test_path:
         test_path = misc.root_path / "tests"
 
-    pytested = pytest.main(["-x", test_path.as_posix()])
+    if not test_coverage:
+        pytest_args = ["-x", test_path.as_posix()]
+    else:
+        pytest_args = ["-x", "--cov", "./", test_path.as_posix()]
+
+    pytested = pytest.main(pytest_args)
 
     if pytested == 1:
         raise Exception("Pytest failed")
